pub fn is_block_terminator(opcode: Op) -> boolExpand description
Returns true if the given opcode is for a terminator instruction.
https://registry.khronos.org/SPIR-V/specs/unified1/SPIRV.html#Termination
pub fn is_block_terminator(opcode: Op) -> boolReturns true if the given opcode is for a terminator instruction.
https://registry.khronos.org/SPIR-V/specs/unified1/SPIRV.html#Termination