pub struct CoreInstructionTable;Expand description
The table for all SPIR-V core instructions.
This table is staic data stored in the library.
Implementations
Sourceimpl CoreInstructionTable
impl CoreInstructionTable
Sourcepub fn lookup_opcode(opcode: u16) -> Option<&'static Instruction<'static>>
pub fn lookup_opcode(opcode: u16) -> Option<&'static Instruction<'static>>
Looks up the given opcode in the instruction table and returns
a reference to the instruction grammar entry if found.
Sourcepub fn get(opcode: Op) -> &'static Instruction<'static>
pub fn get(opcode: Op) -> &'static Instruction<'static>
Returns a reference to the instruction grammar entry with the given
opcode.
pub fn iter() -> impl Iterator<Item = &'static Instruction<'static>>