InstructionTable

Struct InstructionTable 

pub struct InstructionTable<Op: Into<Word> + Clone + Copy + Eq + 'static>(/* private fields */);
The table for all SPIR-V core instructions.

This table is static data stored in the library.

Implementations

Source

impl<Op: Into<Word> + Clone + Copy + Eq> InstructionTable<Op>

pub fn lookup_opcode( &self, opcode: Word, ) -> Option<&'static BaseInstruction<'static, Op>>

Looks up the given opcode in the instruction table and returns a reference to the instruction grammar entry if found.

pub fn get(&self, opcode: Op) -> &'static BaseInstruction<'static, Op>

Returns a reference to the instruction grammar entry with the given opcode.

pub fn iter( &self, ) -> impl Iterator<Item = &'static BaseInstruction<'static, Op>>