pub struct OpenCLStd100InstructionTable;Expand description
The table for all OpenCLstd100 extended instructions.
This table is staic data stored in the library.
Implementations
Sourceimpl OpenCLStd100InstructionTable
impl OpenCLStd100InstructionTable
Sourcepub fn lookup_opcode(
opcode: u32,
) -> Option<&'static ExtendedInstruction<'static>>
pub fn lookup_opcode( opcode: u32, ) -> Option<&'static ExtendedInstruction<'static>>
Looks up the given opcode in the instruction table and returns
a reference to the instruction grammar entry if found.
Sourcepub fn get(opcode: CLOp) -> &'static ExtendedInstruction<'static>
pub fn get(opcode: CLOp) -> &'static ExtendedInstruction<'static>
Returns a reference to the instruction grammar entry with the given
opcode.
pub fn iter() -> impl Iterator<Item = &'static ExtendedInstruction<'static>>